/******************************************************************************
*
* project name:    TI-Memory
* file name:       cursor.c (initial code taken from S1P2 tutorial)
* initial date:    07/11/2000
* authors:         thomas.nussbaumer@gmx.net
*                  marcos.lopez@wol.es
*
* description:     clock stuff
*
* $Id: clock.c,v 1.2 2002/11/14 14:02:53 nussbaumer Exp $
*
******************************************************************************/

INT_HANDLER oldint5 = NULL;  // will hold the address of the previous handler later

volatile short mseconds50 = 0; // counts in 50ms steps (not exact 50ms, but 1000/19 ms)
volatile short seconds    = 0; // counts seconds
volatile short minutes    = 0; // counts minutes
volatile short hours      = 0; // counts hours
volatile short resettime  = 1; // used to signal a reset clock
volatile short running    = 1;
volatile short outputtime = 0;


/*===========================================================================*/
/* our own interrupt handler hooked on interrupt 5 (updates clock variables) */
/*===========================================================================*/
DEFINE_INT_HANDLER (myint5handler) {
    if (resettime) {
        mseconds50=seconds=minutes=hours=resettime=0;
    }
    else if (running) {
        mseconds50++;
        if (mseconds50 == 19) {
            mseconds50 = 0;
            seconds++;

            //-------------------------------------------------------
            // we have counted a second, let's update the time output
            // (done within the GetUserInput() routine)
            //-------------------------------------------------------
            outputtime=1;

            if (seconds == 60) {
                seconds = 0;
                minutes++;
                if (minutes == 60) {
                   minutes = 0;
                   hours++;
                   if (hours == 24) hours = 0;
                }
            }
        }
    }
    //---------------------------------------------------------
    // execute the old interrupt handler at the end of our own
    // to make sure that other timers which are generated using
    // the AMS timer routines like OSRegisterTimer() will still
    // work correctly
    //---------------------------------------------------------
    ExecuteHandler(oldint5);
}


//=============================================================================
// Revision History
//=============================================================================
//
// $Log: clock.c,v $
// Revision 1.2  2002/11/14 14:02:53  nussbaumer
// changes for AMS 2.08/V200 support and for TIGCC 0.94
//
// Revision 1.1  2000/11/14 19:34:38  Thomas Nussbaumer
// initial version
//
//
